@@ -1,7 +1,7 @@
 """
 Type annotations for compute-optimizer service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/literals/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/literals/)
 
 Usage::
 
@@ -538,6 +538,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
